@@ -1,6 +1,7 @@
 ;;; GNU Guix --- Functional package management for GNU
 ;;; Copyright © 2014 Eric Bavier <bavier@member.fsf.org>
 ;;; Copyright © 2015 Mark H Weaver <mhw@netris.org>
+;;; Copyright © 2018 Tobias Geerinckx-Rice <me@tobias.gr>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -23,6 +24,7 @@
   #:use-module (guix download)
   #:use-module (guix build-system python)
   #:use-module (gnu packages)
+  #:use-module (gnu packages databases)
   #:use-module (gnu packages gtk)
   #:use-module (gnu packages glib)
   #:use-module (gnu packages image)
@@ -51,16 +53,19 @@
     (inputs
      `(("pygtk"             ,python2-pygtk)
        ("sqlalchemy"        ,python2-sqlalchemy)
+       ("python-lxml"       ,python2-lxml)
        ("python-pillow"     ,python2-pillow)
-       ("elib.intl"         ,python2-elib.intl)
-       ;; XXX: This really isn't an input for gourmet but of pillow.  Making
-       ;; it a propagated input in pillow doesn't seem to get its site path
-       ;; into gourmet's wrapper's PYTHONPATH however...
-       ("python-setuptools" ,python2-setuptools)))
+       ("elib.intl"         ,python2-elib.intl)))
     (arguments
      `(#:python ,python-2               ;exception and print syntax
-       #:tests? #f))                    ;tests look bitrotted
-    (home-page "http://thinkle.github.io/gourmet/")
+       #:tests? #f                      ;tests look bitrotted
+       #:phases
+       (modify-phases %standard-phases
+         (replace 'install
+           (lambda* (#:key make-flags #:allow-other-keys)
+             (invoke "python" "setup.py" "install" "--prefix"
+                     (assoc-ref %outputs "out")))))))
+    (home-page "https://thinkle.github.io/gourmet/")
     (synopsis "Recipe organizer")
     (description
      "Gourmet Recipe Manager is a recipe organizer that allows you to collect,
