@@ -1,6 +1,7 @@
 ;;; GNU Guix --- Functional package management for GNU
 ;;; Copyright © 2013, 2014, 2015 Andreas Enge <andreas@enge.fr>
-;;; Copyright © 2015, 2016 Ricardo Wurmus <rekado@elephly.net>
+;;; Copyright © 2015, 2016, 2018 Ricardo Wurmus <rekado@elephly.net>
+;;; Copyright © 2018 Tobias Geerinckx-Rice <me@tobias.gr>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -21,6 +22,7 @@
   #:use-module ((guix licenses)
                 #:select (non-copyleft isc gpl2 lgpl2.1 lgpl2.1+))
   #:use-module (guix packages)
+  #:use-module (guix git-download)
   #:use-module (guix download)
   #:use-module (guix build-system cmake)
   #:use-module (guix build-system gnu)
@@ -119,41 +121,33 @@ Java Lucene text search engine API to C++.")
 (define-public lrdf
   (package
     (name "lrdf")
-    (version "0.5.0")
+    (version "0.6.1")
     (source (origin
-              (method url-fetch)
-              (uri (string-append "https://github.com/swh/LRDF/archive/"
-                                  version ".tar.gz"))
-              (file-name (string-append name "-" version ".tar.gz"))
+              (method git-fetch)
+              (uri (git-reference
+                    (url "https://github.com/swh/LRDF.git")
+                    (commit (string-append "v" version))))
+              (file-name (git-file-name name version))
               (sha256
                (base32
-                "18p2flb2sv2hq6w2qkd29z9c7knnwqr3f12i2srshlzx6vwkm05s"))))
+                "00wzkfb8y0aqd519ypz067cq099dpc89w69zw8ln39vl6f9x2pd4"))))
     (build-system gnu-build-system)
     (arguments
      '(#:phases
        (modify-phases %standard-phases
          (add-after 'unpack 'remove-out-of-tree-references
            (lambda _
-             ;; remove symlinks to files in /usr/
-             (delete-file-recursively "m4")
-             (for-each delete-file '("config.guess"
-                                     "config.sub"
-                                     "depcomp"
-                                     "install-sh"
-                                     "ltmain.sh"
-                                     "missing"))
              ;; remove_test depends on an out-of-tree RDF file
              (substitute* "examples/Makefile.am"
                (("instances_test remove_test") "instances_test")
                (("\\$\\(TESTS\\) remove_test") "$(TESTS)"))
              #t))
-         (add-after 'remove-out-of-tree-references 'autoreconf
-           (lambda _
-             (zero? (system* "autoreconf" "-vfi")))))))
+         ;; The default bootstrap phase executes autogen.sh, which fails.
+         (replace 'bootstrap
+           (lambda _ (invoke "autoreconf" "-vif") #t)))))
     (inputs
      `(("raptor" ,raptor2)
        ("cyrus-sasl" ,cyrus-sasl)
-       ("openssl" ,openssl)
        ("zlib" ,zlib)))
     (native-inputs
      `(("autoconf" ,autoconf)
@@ -238,14 +232,14 @@ and triple stores.")
 (define-public serd
   (package
     (name "serd")
-    (version "0.26.0")
+    (version "0.30.0")
     (source (origin
              (method url-fetch)
-             (uri (string-append "http://download.drobilla.net/serd-"
+             (uri (string-append "https://download.drobilla.net/serd-"
                                  version ".tar.bz2"))
              (sha256
               (base32
-               "164j43am4hka2vbzw4n52zy7rafgp6kmkgbcbvap368az644mr73"))))
+               "1yyfyvc6kwagi5w43ljp1bbjdvdpmgpds74lmjxycm91bkx0xyvf"))))
     (build-system waf-build-system)
     (arguments
      `(#:tests? #f ; no check target
@@ -256,8 +250,9 @@ and triple stores.")
           (lambda* (#:key outputs #:allow-other-keys)
             (setenv "LDFLAGS"
                     (string-append "-Wl,-rpath="
-                                   (assoc-ref outputs "out") "/lib")))))))
-    (home-page "http://drobilla.net/software/serd/")
+                                   (assoc-ref outputs "out") "/lib"))
+            #t)))))
+    (home-page "https://drobilla.net/software/serd/")
     (synopsis "Library for RDF syntax supporting Turtle and NTriples")
     (description
      "Serd is a lightweight C library for RDF syntax which supports reading
@@ -271,14 +266,14 @@ ideal (e.g. in LV2 implementations or embedded applications).")
 (define-public sord
   (package
     (name "sord")
-    (version "0.16.0")
+    (version "0.16.2")
     (source (origin
              (method url-fetch)
-             (uri (string-append "http://download.drobilla.net/sord-"
+             (uri (string-append "https://download.drobilla.net/sord-"
                                  version ".tar.bz2"))
              (sha256
               (base32
-               "0nh3i867g9z4kdlnk82cg2kcw8r02qgifxvkycvzb4vfjv4v4g4x"))))
+               "13fshxwpipjrvsah1m2jw1kf022z2q5vpw24bzcznglgvms13x89"))))
     (build-system waf-build-system)
     (arguments
      `(#:tests? #f ; no check target
@@ -289,12 +284,13 @@ ideal (e.g. in LV2 implementations or embedded applications).")
           (lambda* (#:key outputs #:allow-other-keys)
             (setenv "LDFLAGS"
                     (string-append "-Wl,-rpath="
-                                   (assoc-ref outputs "out") "/lib")))))))
+                                   (assoc-ref outputs "out") "/lib"))
+            #t)))))
     (inputs
      `(("serd" ,serd)))
     (native-inputs
      `(("pkg-config" ,pkg-config)))
-    (home-page "http://drobilla.net/software/sord/")
+    (home-page "https://drobilla.net/software/sord/")
     (synopsis "C library for storing RDF data in memory")
     (description
      "Sord is a lightweight C library for storing RDF data in memory.")
