@@ -466,18 +466,6 @@ main (int argc, char *argv[])
     {
       settings.processEnvironment ();
 
-      /* Hackily help 'local-store.cc' find our 'guix-authenticate' program, which
-	 is known as 'OPENSSL_PATH' here.  */
-      std::string search_path;
-      search_path = settings.nixLibexecDir;
-      if (getenv ("PATH") != NULL)
-	{
-	  search_path += ":";
-	  search_path += getenv ("PATH");
-	}
-
-      setenv ("PATH", search_path.c_str (), 1);
-
       /* Use our substituter by default.  */
       settings.substituters.clear ();
       settings.set ("build-use-substitutes", "true");
